=====================
Configuration Options
=====================

The following is an overview of all available configuration options in Nova.
For a sample configuration file, refer to :doc:`sample`.

.. show-options::
   deepaas

Logging options
---------------
.. show-options::
   oslo.log
